JournalExt

Trait JournalExt 

pub trait JournalExt: JournalTr<State = EvmState> {
    // Required method
    fn journal(&self) -> &[JournalEntry];
}
Extends the journal with additional methods that are used by the inspector.

Required Methods

fn journal(&self) -> &[JournalEntry]

Get the journal entries that are created from last checkpoint. new checkpoint is created when sub call is made.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<'a, T: 'a + JournalExt + ?Sized> JournalExt for &'a mut T
where &'a mut T: JournalTr<State = EvmState>,

Source

fn journal(&self) -> &[JournalEntry]

Source

impl<DB: Database> JournalExt for Journal<DB>

Source

fn journal(&self) -> &[JournalEntry]

Source

impl<T: JournalExt + ?Sized> JournalExt for Box<T>
where Box<T>: JournalTr<State = EvmState>,

Source

fn journal(&self) -> &[JournalEntry]

Implementors